summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authordengg <dengg@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2003-09-17 21:06:30 +0000
committerdengg <dengg@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2003-09-17 21:06:30 +0000
commit29fad93bb6e8ee1078e659223334cc9246349a7f (patch)
tree5f2de6ca3eba4901ef6f7641d3602e07bee51bc1
parentba6ebd2b7fd4f044096e80d36cc293459cae7edb (diff)
downloadATCD-29fad93bb6e8ee1078e659223334cc9246349a7f.tar.gz
ChangeLogTag: Wed Sep 17 16:05:13 2003 Gan Deng <gan.deng@vanderbilt.edu>
-rw-r--r--TAO/ChangeLog9
-rw-r--r--TAO/tests/Bug_1551_Regression/README5
-rwxr-xr-xTAO/tests/Bug_1551_Regression/run_test.pl4
3 files changed, 16 insertions, 2 deletions
diff --git a/TAO/ChangeLog b/TAO/ChangeLog
index 7f96985c640..84b270b7094 100644
--- a/TAO/ChangeLog
+++ b/TAO/ChangeLog
@@ -1,3 +1,11 @@
+Wed Sep 17 16:05:13 2003 Gan Deng <gan.deng@vanderbilt.edu>
+
+ * tests/Bug_1551_Regression/README
+ * tests/Bug_1551_Regression/run_test.pl
+
+ Added the README file about this regression test.
+ Modified the testing times in the run_test.pl file.
+
Wed Sep 17 15:24:01 2003 Pradeep Gore <pradeep@oomworks.com>
* orbsvcs/examples/Notify/ThreadPool/Supplier_Client.h:
@@ -7,6 +15,7 @@ Wed Sep 17 15:24:01 2003 Pradeep Gore <pradeep@oomworks.com>
solaris regarding hiding the ACE_Shared_Object::init signature.
+>>>>>>> 1.2548
Wed Sep 17 13:29:31 2003 Chad Elliott <elliott_c@ociweb.com>
* tao/extra_core.mpb:
diff --git a/TAO/tests/Bug_1551_Regression/README b/TAO/tests/Bug_1551_Regression/README
new file mode 100644
index 00000000000..ffecd8abf8d
--- /dev/null
+++ b/TAO/tests/Bug_1551_Regression/README
@@ -0,0 +1,5 @@
+A regression test for [BUGID:1551].
+
+The ORB might deadlock if one tries send messages while handling
+exceptions in AMI. Now the bug has been fixed and this test
+should hang. \ No newline at end of file
diff --git a/TAO/tests/Bug_1551_Regression/run_test.pl b/TAO/tests/Bug_1551_Regression/run_test.pl
index e20eec9cb60..edb7803c237 100755
--- a/TAO/tests/Bug_1551_Regression/run_test.pl
+++ b/TAO/tests/Bug_1551_Regression/run_test.pl
@@ -20,7 +20,7 @@ local $start_time = time();
local $max_running_time = 600; # 10 minutes
local $elapsed = time() - $start_time;
-local $ntimes = 100 ; # run test for 100 times
+local $ntimes = 50 ; # run test for 50 times
local $n = 0;
while($n < $ntimes) {
@@ -39,7 +39,7 @@ $client2 = $CL2->Spawn ();
$client3 = $CL3->Spawn ();
-sleep (60);
+sleep (30);
$SV->WaitKill (3) unless $sv1 < 0;
$CL1->WaitKill (3);
$CL2->WaitKill (3);